import { useFormik } from 'formik';
import { useState } from 'react';
import {
  Box,
  Button,
  TextField,
  CircularProgress,
  InputAdornment,
  IconButton,
  Snackbar,
  Alert,
  Typography,
  Paper
} from '@mui/material';
import { PhotoCamera, Close } from '@mui/icons-material';
import { API_URL } from '../config';

function PostForm({ onPostCreated }) {
  const [preview, setPreview] = useState('');
  const [snackbar, setSnackbar] = useState({ open: false, message: '', severity: 'success' });

  const formik = useFormik({
    initialValues: {
      text: '',
      image: null
    },
    onSubmit: async (values, { setSubmitting, resetForm }) => {
      try {
        const formData = new FormData();
        if (values.text) formData.append('text', values.text);
        if (values.image) formData.append('image', values.image);

        const response = await fetch(`${API_URL}/posts/`, {
          method: 'POST',
          body: formData,
        });

        if (!response.ok) throw new Error('Ошибка сервера');

        const data = await response.json();
        onPostCreated(data.vector);
        resetForm();
        setPreview('');
        showSnackbar('Пост успешно создан!', 'success');
      } catch (error) {
        showSnackbar(error.message || 'Ошибка создания поста', 'error');
      } finally {
        setSubmitting(false);
      }
    }
  });

  const handleImageChange = (e) => {
    const file = e.target.files[0];
    if (file) {
      formik.setFieldValue('image', file);
      setPreview(URL.createObjectURL(file));
    }
  };

  const showSnackbar = (message, severity) => {
    setSnackbar({ open: true, message, severity });
  };

  return (
    <Paper elevation={3} sx={{ p: 3, mb: 4, maxWidth: 600, mx: 'auto' }}>
      <Typography variant="h5" gutterBottom component="div">
        Новый пост
      </Typography>

      <form onSubmit={formik.handleSubmit}>
        <TextField
          fullWidth
          multiline
          minRows={4}
          name="text"
          value={formik.values.text}
          onChange={formik.handleChange}
          placeholder="Текст поста..."
          variant="outlined"
          margin="normal"
          InputProps={{
            endAdornment: (
              <InputAdornment position="end">
                <input
                  accept="image/*"
                  style={{ display: 'none' }}
                  id="image-upload"
                  type="file"
                  onChange={handleImageChange}
                />
                <label htmlFor="image-upload">
                  <IconButton component="span" color="primary">
                    <PhotoCamera />
                  </IconButton>
                </label>
              </InputAdornment>
            )
          }}
        />

        {preview && (
          <Box sx={{ mt: 2, position: 'relative' }}>
            <img
              src={preview}
              alt="Preview"
              style={{ 
                maxWidth: '100%', 
                borderRadius: 4,
                maxHeight: 200,
                objectFit: 'cover'
              }}
            />
            <IconButton
              onClick={() => {
                formik.setFieldValue('image', null);
                setPreview('');
              }}
              sx={{ position: 'absolute', right: 8, top: 8, bgcolor: 'background.paper' }}
            >
              <Close />
            </IconButton>
          </Box>
        )}

        <Box sx={{ mt: 3, display: 'flex', justifyContent: 'flex-end' }}>
          <Button
            type="submit"
            variant="contained"
            color="primary"
            disabled={formik.isSubmitting || (!formik.values.text && !formik.values.image)}
            startIcon={formik.isSubmitting && <CircularProgress size={20} />}
          >
            {formik.isSubmitting ? 'Отправка...' : 'Опубликовать'}
          </Button>
        </Box>
      </form>

      <Snackbar
        open={snackbar.open}
        autoHideDuration={6000}
        onClose={() => setSnackbar(prev => ({ ...prev, open: false }))}
      >
        <Alert severity={snackbar.severity} sx={{ width: '100%' }}>
          {snackbar.message}
        </Alert>
      </Snackbar>
    </Paper>
  );
}

export default PostForm;